#
# spec file for package qqc2-desktop-style
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _tar_path 5.56
Name:           qqc2-desktop-style
Version:        5.56.0
Release:        1.1
Summary:        A Qt Quick Controls 2 Style for Desktop UIs
License:        GPL-2.0-or-later
Group:          Development/Libraries/KDE
URL:            https://www.kde.org
Source:         https://download.kde.org/stable/frameworks/%{_tar_path}/qqc2-desktop-style-%{version}.tar.xz
# PATCH-FIX-OPENSUSE
Patch0:         fix-build-with-gcc48.patch
# PATCH-FIX-OPENSUSE
Patch1:         0001-Fix-MobileTextActionsToolBar.qml-with-Qt-5.9.patch
BuildRequires:  extra-cmake-modules >= 0.0.8
# For dir ownership
BuildRequires:  kconfigwidgets-devel
BuildRequires:  kf5-filesystem
BuildRequires:  kiconthemes-devel
BuildRequires:  kirigami2-devel
BuildRequires:  cmake(Qt5Core) >= 5.9.1
BuildRequires:  cmake(Qt5Gui)
BuildRequires:  cmake(Qt5Network)
BuildRequires:  cmake(Qt5Quick)
BuildRequires:  cmake(Qt5QuickControls2)
BuildRequires:  cmake(Qt5Svg)
BuildRequires:  cmake(Qt5Widgets)
Requires:       libqt5-qtquickcontrols2
# plasma5-workspace sets up the env variables so that this theme
# is picked by default. It still works fine without it (no requires),
# but looks better with it. By itself plasma5-workspace does not use
# it (yet), so only install it with libqt5-qtquickcontrols2.
Supplements:    packageand(plasma5-workspace:libqt5-qtquickcontrols2)
# For KUA users
Provides:       plasma5-qqc2-style = %{version}
Obsoletes:      plasma5-qqc2-style < %{version}

%description
A Qt Quick Controls 2 style engine that uses the desktop style
to draw controls with QStyle.

%package devel
Summary:        Development Files for Qt Quick Controls 2 Desktop Style
Group:          Development/Libraries/KDE
Requires:       %{name} = %{version}
Requires:       extra-cmake-modules

%description devel
This file contains cmake files to be used by projects that depend on
qqc2-desktop-style.
Usually not needed as it is only a runtime dependency.

%prep
%setup -q
%if 0%{?suse_version} < 1500
%patch0 -p1
%endif
%patch1 -p1
%if 0%{?suse_version} == 1500
sed -i -e "s/^set *(REQUIRED_QT_VERSION 5.10.0)$/set(REQUIRED_QT_VERSION 5.9.0)/" CMakeLists.txt
%endif

%build
%cmake_kf5 -d build
%make_jobs

%install
%kf5_makeinstall -C build

%files
%license LICENSE*
%{_kf5_qmldir}/QtQuick/Controls.2/org.kde.desktop/
%dir %{_kf5_qmldir}/org/
%dir %{_kf5_qmldir}/org/kde/
%dir %{_kf5_plugindir}/kf5/kirigami/
%{_kf5_plugindir}/kf5/kirigami/org.kde.desktop.so
%{_kf5_qmldir}/org/kde/qqc2desktopstyle/

%files devel
%{_kf5_libdir}/cmake/KF5QQC2DeskopStyle/

%changelog
* Sun Mar 10 2019 lbeltrame@kde.org
- Update to 5.56.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.56.0.php
- Changes since 5.55.0:
  * Use PointingHand when hovering links in Label
  * Respect the display property of buttons
  * clicking on empty areas behaves like pgup/pgdown (kde#402578)
  * Support icon on ComboBox
  * support text positioning api
  * Support icons from local files in buttons
  * Use the correct cursor when hovering over the editable part of a spinbox
* Fri Feb 15 2019 alarrosa@suse.com
- Add 0001-Fix-MobileTextActionsToolBar.qml-with-Qt-5.9.patch (by Fabian Vogt)
  to fix an issue with Qt 5.9
- Downgrade the Qt version requirement to build with 5.9
* Sun Feb 10 2019 lbeltrame@kde.org
- Update to 5.55.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.55.0.php
- Changes since 5.54.0:
  * Fix combobox initial sizing (kde#403736)
  * Set combobox popups to be modal (kde#403403)
  * Tab bar test
  * partly revert 4f00b0cabc1230fdf
  * Word-wrap long tooltips (kde#396385)
  * ComboBox: fix default delegate
  * Fake mousehover whilst combobox is open
  * Set CombooBox QStyleOptionState == On rather than Sunken to match qwidgets
  * Fix ComboBox
  * Always draw the tooltip on top of everything else
  * Support a tooltip on a MouseArea
  * Minor: Use {} for initializing flags
  * Minor: Use nullptr
  * do not force text display for ToolButton
* Mon Jan 14 2019 lbeltrame@kde.org
- Update to 5.54.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.54.0.php
- Changes since 5.53.0:
  * Fix warning
  * Fix menu item width when the delegate is overriden (kde#401792)
  * Fix warnings
  * Rotate busy indicator clockwise
  * same behavior as Kirigami ScrollablePage
  * force checkboxes/radios to be square
* Sun Dec  9 2018 lbeltrame@kde.org
- Update to 5.53.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.53.0.php
- Changes since 5.52.0:
  * consistent sizing of item compared to QWidgets
  * emit activated
  * same behavior as qwidgets comboboxes
  * fix Menu sizing
  * default values for ToolTip
  * proper line widths
  * make sure flickables are pixelAligned
  * Fix compilation
  * Support for QGuiApplication-based apps (kde#396287)
  * touchscreen text controls
  * Size according to specified icon width and height
  * Honor flat property of buttons
  * Remove qt include prefix
  * Fix issue where there's only one element on the menu
* Sun Nov 11 2018 lbeltrame@kde.org
- Update to 5.52.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.52.0.php
- Changes since 5.51.0:
  * No code changes since 5.51.0
* Tue Oct 16 2018 Luca Beltrame <lbeltrame@kde.org>
- Run spec-cleaner
* Mon Oct 15 2018 lbeltrame@kde.org
- Update to 5.51.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.51.0.php
- Changes since 5.50.0:
  * small default padding when there is a background
  * Make it compile with "KDEFrameworkCompilerSettings"
* Thu Sep 13 2018 lbeltrame@kde.org
- Update to 5.50.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.50.0.php
- Changes since 5.49.0:
  * None
* Sun Aug 19 2018 christophe@krop.fr
- Update to 5.49.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.49.0.php
- Changes since 5.48.0:
  * Improve sizing of menus (kde#396841)
  * Remove double comparison
  * Port away from string-based connects
  * check for valid icon
* Mon Jul 16 2018 lbeltrame@kde.org
- Update to 5.48.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.48.0.php
- Changes since 5.47.0:
  * no pixel values in checkindicator
  * own sizehit for sliders
  * use RadioIndicator for everybody
  * Don't overflow around popups
  * on Qt<5.11 the control palette is completely ignored
  * import kirigami 2.4
  * anchor button background
* Tue Jun 12 2018 lbeltrame@kde.org
- Update to 5.47.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.47.0.php
- Changes since 5.46.0:
  * Use pallet property only when using qtquickcontrols 2.4
  * work with Qt<5.10
  * add missing import
  * fix height of tabbar
  * Use Control.palette
  * --warnings
  * [RadioButton] Rename "control" to "controlRoot"
  * Don't set explicit spacing on RadioButton/CheckBox
  * [FocusRect] Use manual placement instead of anchors
  * import focusrect
  * import FocusRect
  * It turns out the flickable in a scrollview is the contentItem
  * Use override
  * Show focus rect when CheckBox or RadioButton are focused
  * hacky fix to scrollview detection
  * don't reparent the flickable to the mousearea
  * Add test file for ScrollView { TextArea {} }
  * [TabBar] Switch tabs with mouse wheel
  * Fix warning
  * Control must not have children (kde#394134)
  * constrain scroll (kde#393992)
- Dropped patches, now upstream:
  * control-must-not-have-children.patch
* Sun May 13 2018 lbeltrame@kde.org
- Update to 5.46.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.46.0.php
- Changes since 5.45.0:
  * export layout paddings from qstyle, start from Control
  * [ComboBox] Fix mouse wheel handling
  * make the mousearea not interfere with controls
  * fix acceptableInput
  * remove useless debug
  * Fix warning
- Add upstream patch to fix control panel layouts (kde#394134):
  * control-must-not-have-children.patch
* Mon Apr 16 2018 wbauer@tmo.at
- Add fix-build-with-gcc48.patch to make it compile with gcc 4.8 on
  Leap 42.3
* Sat Apr 14 2018 lbeltrame@kde.org
- Update to 5.45.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.45.0.php
- Changes since 5.44.0:
  * fix rendering when disabled
  * better layout
  * experimental support for auto mnemonics
  * We depend against 5.8.0
  * Make sure we are taking into account hte size of the element when styling
  * Fix font rendering for non-HiDPI and integer scale factors (kde#391780)
  * e our way to handle shortcuts
  * fix icons colors with colorsets
  * fix icon colors for toolbuttons
* Mon Mar 12 2018 lbeltrame@kde.org
- Update to 5.44.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.44.0.php
- Changes since 5.43.0:
  * Fix syntax error in previous commit, detected by launching ruqola
  * Show a radiobutton when we are showing an exclusive control
  * fix some Qt 5.9 bugs
  * implement MenuBarItem
  * fix logic
  * implement DelayButton
  * New component: round button
  * take into account toolbar position
  * support colors for icons in buttons
  * support --reverse
  * icons in Menu fully functional
  * consistent shadows with the new breeze style
  * ame behavior as qwidget menus
  * make icons actually work
  * Some QStyles seem to not return sensible pixelmetrics here
  * first rough icons support
  * don't wrap around with mouse wheel
* Mon Feb 12 2018 lbeltrame@kde.org
- Update to 5.43.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.43.0.php
- Changes since 5.42.0:
  * use the inactive or disabled color group when needed
  * Apply some C++11 niceties, styling consistency
  * Add BusyIndicator to the styled controls list
  * remove flicker when hovering scrollbar
  * Cache KColorScheme instances
* Tue Jan 16 2018 lbeltrame@kde.org
- Update to 5.42.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.42.0.php
- Changes since 5.41.0:
  * simplify and don't try to block mouse events
  * if no wheel.pixelDelta, use global wheel scroll lines
  * desktop tabbars have different widths for each tab
  * ensure a non 0 size hint
* Sun Dec 17 2017 lbeltrame@kde.org
- Update to 5.41.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.41.0.php
- Changes since 5.40.0:
  * determine QQC2 version at build time (kde#386289)
  * by default, keep the background invisible
  * add a background in ScrollView
* Tue Nov 14 2017 wbauer@tmo.at
- Fix QtQuickControls2 BuildRequires, it needs the devel package to
  build
* Mon Nov 13 2017 lbeltrame@kde.org
- Update to 5.40.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.40.0.php
- Changes since 5.39.0:
  * Improve compilation as a static plugin.
  * make the radiobutton a radiobutton
  * use qstyle to paint the Dial
  * use a ColumnLayout for menus
  * fix Dialog
  * remove invalid group property
  * Add .arcconfig
  * Fix formatting of the md file so it matches the other modules
  * behavior of combobox closer to qqc1
  * workaround for QQuickWidgets
* Mon Oct 23 2017 lbeltrame@kde.org
- Update to 5.39.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.39.0.php
- Changes since 5.38.0:
  * Too many to list here
* Sat Aug 19 2017 fabian@ritter-vogt.de
- Initial packaging
